@@ -1,11 +1,13 @@
 from django.conf import settings
 from django.core.mail.backends.base import BaseEmailBackend
 
-from djcelery_email.tasks import SendEmailTask
+from djcelery_email.tasks import send_email
 
 
 class CeleryEmailBackend(BaseEmailBackend):
-    
+
     def send_messages(self, email_messages):
+        results = []
         for msg in email_messages:
-            SendEmailTask.delay(msg)
\ No newline at end of file
+            results.append(send_email.delay(msg))
+        return results
